exceptiontools.MissingSpannerError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError

.. autoclass:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError.__unicode__
   :noindex:
